#
# spec file for package python-typed-ast
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-typed-ast
Version:        1.5.4
Release:        2.3
Summary:        A fork of Python 2 and 3 ast modules with type comment support
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/python/typed_ast
Source0:        https://files.pythonhosted.org/packages/source/t/typed_ast/typed_ast-%{version}.tar.gz
# PATCH-FIX-UPSTREAM use-PyUnicode_DecodeUnicodeEscape.patch gh#python/typed_ast#172 mcepl@suse.com
# Use PyUnicode_DecodeUnicodeEscape directly
Patch0:         use-PyUnicode_DecodeUnicodeEscape.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
typed_ast is a Python 3 package that provides a Python 2.7 and Python 3
parser similar to the standard ast library. Unlike ast, the parsers in
typed_ast include PEP 484 type comments and are independent of the version of
Python under which they are run. The typed_ast parsers produce the standard
Python AST (plus type comments), and are both fast and correct, as they are
based on the CPython 2.7 and 3.6 parsers.

%prep
%setup -q -n typed_ast-%{version}
%autopatch -p1

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitearch}/*

%changelog
* Tue May  9 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Sun May 22 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Release version 1.5.4 (#189)
  - Do not include now private code.h (#188)
  As of https://github.com/python/cpython/pull/32385 the header
  code.h is private but directly included into Python.h
  - Fix Python 3.11 support (#187)
  The compilation error on master is:
  ```
    ast3/Parser/tokenizer.c:1991:10: error: implicit declaration of function '_Py_dup' is invalid in C99 [-Werror,-Wimplicit-function-declaration]
    fd = _Py_dup(fd);
    ^
    1 error generated.
  ```
  Probably as a result of https://github.com/python/cpython/pull/30484
  Just declaring it seems to fix things.
  Add a (slightly) hacky way of testing Python 3.11 in CI prior to manylinux / cibuildwheel support.
  - Bump version to 1.5.4.dev0 (#186)
* Tue Apr 19 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Release version 1.5.3 (#185)
  - FIX: Account form stdbool.h being included in Python.h (#184)
  As of CPython 3.11 (via https://github.com/python/cpython/pull/29883) stdbool.h
  is now included in Python.h so do attempt to redefine bool/true/false.
  - Bump version to 1.5.3.dev0
* Thu Jan 27 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Release version 1.5.2
  - Add support for building aarch64 wheels (#182)
  Co-authored-by: Shantanu <12621235+hauntsaninja@users.noreply.github.com>
  - Remove update process document (#177)
  typed_ast will not be updated to support syntax past Python 3.8 as
  Python 3.8's ast module now incorporates the features of typed_ast.
  - Bump version to 1.5.2.dev0
* Sun Dec  5 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- Release version 1.5.1 (#181)
  - Fix #167: Port ast27 to Python 3.11 (#176)
  Copy _PyLong_DigitValue table from Python 3.10 as "digitvalue" in
  ast27/Python/mystrtoul.c. The symbol has been removed from the public
  Python 3.11 C API.
  - Bump version to 1.5.1.dev0
* Thu Nov 18 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add patch use-PyUnicode_DecodeUnicodeEscape.patch:
  * Use PyUnicode_DecodeUnicodeEscape directly, rather than wrapping it.
* Sat Nov 13 2021 Dirk Müller <dmueller@suse.com>
- update to 1.5.0:
  * Drop python 3.5 support
  * Define _PyUnicode_DecodeUnicodeEscape even on Python 3.6+
  * Recommend ast on Python 3.8+
* Tue Apr 13 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.4.3:
  - Download wheels for 3.9 as well
  - Download aarch64 wheels (#154)
  - Allow compilation on python 3.10.0a6 (#155)
  Closes #156. (Except for Apple Silicon.)
  - Fix compilation on python 3.10.0a7 (#158)
  - PyArena was removed from the public api in python/cpython#25007
  - This commit adds two new files (a copy of each for ast27 and ast3):
  * pycore_pyarena.h: Taken from the cpython source code with minimal
    changes
  * pyarena.h: Maps the new, underscored function names to the old
    function names, allowing the code to work on both python 3.10 and
    older versions
  - Add Python 3.10 classifier (#160)
* Thu Dec 31 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- remove obsolete ast27-prefix-exported-symbols.patch, included upstream
- update to version 1.4.2:
  - Fix linker error in debug build (#131)
  - Fix cross compile by adjusting includes (#135)
  - Add note in incompatabilities that PyPy is broken and unsupported (#144)
  - Remove reference to PyNode_ListTree for Python 3.10 (#153)
  - ast27: prefix exported symbols (#152)
  - Add 3.9 to supported versions
* Wed Dec 30 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- Add ast27-prefix-exported-symbols.patch from upstream PR#152 to fix ppc64 and
  s390x builds/tests and run all tests again.
* Fri Dec  4 2020 Benjamin Greiner <code@bnavigator.de>
- Use (fixed in the meantime) pytest_arch macro in order to ignore
  the _build directories from multiple python3 flavors
  gh#openSUSE/python-rpm-macros#66
* Sun May 17 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- disable tests 'test_ignores' and 'test_convert_strs', failing on ppc64, fixes bsc#1171573.
* Sat Jan 18 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.4.1:
  * Clean up old build scripts (#123)
  * Build artifacts for 3.8 (#127)
  * Fix build on cpython (3.9) master branch (#128)
* Mon Jun 17 2019 pgajdos@suse.com
- version update to 1.4.0
  * Fix compilation on Python 3.8
* Fri May 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not use the %%pytest_arch call but expand it as the tests
  seem to need more verbosity otherwise they fail sometimes
  (fishy, but works)
* Tue May  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Use %%pytest_arch
- Add missing fdupes call
* Tue May  7 2019 pgajdos@suse.com
- version update to 1.3.5
  * Counteract PyTuple_SetItem stealing reference in _PyObject_FastCall
    fallback (#104)
- run tests
* Fri May  3 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.3.4:
  * Oops: add the pgenheaders files to the depends lists
- update to version 1.3.3:
  * Don't rely on Python's pgenheaders.h (#101)
- update to version 1.3.2:
  * Fix two out-of-bounds array reads (#99)
* Sun Feb 10 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 1.3.1:
  * Disallow two type comments on one def
  * Fix memory leaks caused by type comment parsing (#91)
  * Fix some broken asserts relating to handling of async keyword (#92)
  * Check NEW_TYPE_COMMENT calls for failure (#93)
- Update to version 1.3.0:
  * Fully incorporate the code from Python 3.7.2
  * Fix some compiler warnings
  * Add a kind field to Bytes as well (#83)
  * Fix await in functions with type comments (#86)
  * Put _ast3 and _ast27 in the typed_ast package (#85)
  * Fix f-string parsing to not think everything is a set (#87)
* Tue Jan 15 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 1.2.0:
  * Fix conversions.py2to3 on unicode strings (#67)
  * Fix remaining calls to Str without a kind (#68)
  * Add "Python :: 3.7" to the classifiers list
  * Some docs updates (#73)
* Wed Jan  2 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 1.1.1:
  * Add __version__ string and tweak versioning scheme
  * Point to the Python 3.6 commits as examples of how to update typed_ast (
  * Add section on development philosophy
  * Add information about the release process.
  * Document Google Cloud Storage artifact deployment
  * Preserve string kind modifiers
  * Add docs for Str.kind
* Thu Sep 20 2018 Tomáš Chvátal <tchvatal@suse.com>
- Use license macro for license install
* Thu Jul 20 2017 sebix+novell.com@sebix.at
- update to version 1.1.0
  * Vs2010 compilation support (Python 3.3/3.4 support) (#47)
* Tue Jun 27 2017 sebix+novell.com@sebix.at
- use new %%skip_python2 instead of obsolete undefines
* Tue Jun 20 2017 sebix+novell.com@sebix.at
- update to version 1.0.4
  * Add checks for some 3.5+ only syntax (async/await and the @ operator) (#41)
* Wed May 31 2017 sebix+novell.com@sebix.at
- initial package
